==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
var DatePartDeltasDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DatePartDeltasDescriptionMetadata, _super);
    function DatePartDeltasDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePartDeltasDescriptionMetadata.b = function (a) {
        if (DatePartDeltasDescriptionMetadata.a == null) {
            DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
        }
        if (a.g(DatePartDeltasDescriptionMetadata.a)) {
            return;
        }
        a.s(DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.c = function (a) {
        a.item("Date", "Number:double");
        a.item("Month", "Number:double");
        a.item("Year", "Number:double");
        a.item("Hours", "Number:double");
        a.item("Minutes", "Number:double");
        a.item("Seconds", "Number:double");
    };
    DatePartDeltasDescriptionMetadata.d = function (a) {
        DatePartDeltasDescriptionMetadata.b(a);
        a.u("DatePartDeltas", function () { return new DatePartDeltasDescription(); });
        a.t("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.$t = markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
}(Base));
export { DatePartDeltasDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/DatePartDeltasDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DatePartDeltasDescription } from "./DatePartDeltasDescription";
/**
 * @hidden
 */
var DatePartDeltasDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(DatePartDeltasDescriptionMetadata, _super);
    function DatePartDeltasDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DatePartDeltasDescriptionMetadata.b = function (a) {
        if (DatePartDeltasDescriptionMetadata.a == null) {
            DatePartDeltasDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DatePartDeltasDescriptionMetadata.c(DatePartDeltasDescriptionMetadata.a);
        }
        if (a.j(DatePartDeltasDescriptionMetadata.a)) {
            return;
        }
        a.y(DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.c = function (a) {
        a.item("Date", "Number:double");
        a.item("Month", "Number:double");
        a.item("Year", "Number:double");
        a.item("Hours", "Number:double");
        a.item("Minutes", "Number:double");
        a.item("Seconds", "Number:double");
    };
    DatePartDeltasDescriptionMetadata.d = function (a) {
        DatePartDeltasDescriptionMetadata.b(a);
        a.aa("DatePartDeltas", function () { return new DatePartDeltasDescription(); });
        a.z("DatePartDeltas", DatePartDeltasDescriptionMetadata.a);
    };
    DatePartDeltasDescriptionMetadata.$t = markType(DatePartDeltasDescriptionMetadata, 'DatePartDeltasDescriptionMetadata');
    DatePartDeltasDescriptionMetadata.a = null;
    return DatePartDeltasDescriptionMetadata;
}(Base));
export { DatePartDeltasDescriptionMetadata };
